Hy
==

[![Build Status](https://img.shields.io/travis/hylang/hy/master.svg)](https://travis-ci.org/hylang/hy)
[![Downloads](https://img.shields.io/pypi/dm/hy.svg)](https://pypi.python.org/pypi/hy)
[![Version](https://img.shields.io/pypi/v/hy.svg)](https://pypi.python.org/pypi/hy)
[![Coverage Status](https://img.shields.io/coveralls/hylang/hy/master.svg)](https://coveralls.io/r/hylang/hy)

<a href="https://xkcd.com/224/"><img title="We lost the documentation on quantum mechanics. You'll have to decode the regexes yourself." alt="XKCD #224" src="https://raw.github.com/hylang/shyte/18f6925e08684b0e1f52b2cc2c803989cd62cd91/imgs/xkcd.png"></a>

Lisp and Python should love each other. Let's make it happen. [Try it](http://try-hy.appspot.com/).

Hylarious Hacks
---------------

* [Django + Lisp](https://github.com/paultag/djlisp/tree/master/djlisp)
* [Python `sh` Fun](https://twitter.com/paultag/status/314925996442796032)
* [Hy IRC Bot](https://github.com/hylang/hygdrop)
* [miniKanren in Hy](https://github.com/algernon/adderall)

OK, so, why?
------------

Well. Python is awesome. So awesome, that we have so many tools to alter the
language in a *core* way, but we never use them.

Why?

Well, I wrote Hy to help people realize one thing about Python:

It's really awesome.

Oh, and lisps are neat.

![Cuddles the Hacker](https://i.imgur.com/QbPMXTN.png)

(fan art from the one and only [doctormo](http://doctormo.deviantart.com/art/Cuddles-the-Hacker-372184766))

Project
-------

* Code: https://github.com/hylang/hy
* Docs (latest, for use with bleeding-edge github version): http://hylang.org/
* Docs (stable, for use with the PyPI version): http://docs.hylang.org/en/stable/
* Quickstart: http://hylang.org/en/latest/quickstart.html
* Bug reports: We have no bugs! Your bugs are your own! (https://github.com/hylang/hy/issues)
* License: MIT (Expat)
* [Contributor Guidelines & Code of Conduct](https://github.com/hylang/hy/blob/master/CONTRIBUTING.rst)
* IRC: Join #hy on [freenode](https://webchat.freenode.net/)
